@@ -64,12 +64,7 @@ $retrievedata{1} =
 [ 
 [ 
 [ 
-"1 2 1", "7 2 24", "1" 
-]
-],
-[ 
-[ 
-"1 7 1", "7 7 24", "1" 
+"1 1 1", "31 12 24", "1" 
 ] 
 ]
 ]; 
@@ -218,7 +213,7 @@ $vals{1}{1}{genchange} =  #THIS MEANS: CHANGE OF "generic" TYPE, WHICH ARE TRASF
 "/ep/newbox21.idf", # FILE TO BE MODIFIED.
 #[ [ 19 ], # FIRST CHANGE TO BE MADE. THIS MEANS: [ [line_number_to_change1, line_number_to_change2, ... line_number_to_changen], 
 [ [ 19, 20, 21, 22, 34, 35, 66, 67, 79, 82, 95, 96 ], # FIRST CHANGE TO BE MADE. THIS MEANS: [ [line_number_to_change1, line_number_to_change2, ... line_number_to_changen], 
-[ 2 ], [ 0, -1.5 ], [  ], "linear" ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type:"linear"_or_"rotation2d" ]; 
+[ 2 ], [ 0, -1.5 ], [  ], "linear", ","  ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type:"linear"_or_"rotation2d" ]; 
 ]
 ]
 ]
@@ -237,7 +232,7 @@ $vals{1}{2}{genchange} =  #THIS MEANS: CHANGE OF "generic" TYPE, WHICH ARE TRASF
 [ # BKACKET DELIMITING THIS GROUP OF ACTIONS. THERE IS ONLY ONE GROUP OF ACTIONS IN THIS GROUP OF OPERATIONS.
 "/ep/newbox21.idf", # FILE TO BE MODIFIED.
 [ [ 199, 200, 201, 202, 214, 215, 229, 230, 231, 232, 246, 247, 259, 262, 275, 276 ], # FIRST CHANGE TO BE MADE. THIS MEANS: [ [line_number_to_change1, line_number_to_change2, ... line_number_to_changen], 
-[ 2 ], [ 0, -1.5 ], [  ], "linear" ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type:"linear"_or_"rotation2d" ]; 
+[ 2 ], [ 0, -1.5 ], [  ], "linear", ","  ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type:"linear"_or_"rotation2d" ]; 
 ]
 ]
 ]
@@ -255,7 +250,7 @@ $vals{1}{3}{genchange} =  #THIS MEANS: CHANGE OF "generic" TYPE, WHICH ARE TRASF
 [ # BKACKET DELIMITING THIS GROUP OF ACTIONS. THERE IS ONLY ONE GROUP OF ACTIONS IN THIS GROUP OF OPERATIONS.
 "/ep/newbox21.idf", # FILE TO BE MODIFIED.
 [ [ 289, 290, 291, 292, 304, 305, 336, 337, 349, 352, 365, 366 ], # FIRST CHANGE TO BE MADE. THIS MEANS: [ [line_number_to_change1, line_number_to_change2, ... line_number_to_changen], 
-[ 2 ], [ 0, -1.5 ], [  ], "linear" ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type:"linear"_or_"rotation2d" ]; 
+[ 2 ], [ 0, -1.5 ], [  ], "linear", ","  ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type:"linear"_or_"rotation2d" ]; 
 ]
 ]
 ]
@@ -273,7 +268,7 @@ $vals{1}{4}{genchange} =  #THIS MEANS: CHANGE OF "generic" TYPE, WHICH ARE TRASF
 [ # BKACKET DELIMITING THIS GROUP OF ACTIONS. THERE IS ONLY ONE GROUP OF ACTIONS IN THIS GROUP OF OPERATIONS.
 "/ep/newbox21.idf", # FILE TO BE MODIFIED.
 [ [ 379, 380, 381, 382, 394, 395, 426, 427, 439, 442, 455, 456 ], # FIRST CHANGE TO BE MADE. THIS MEANS: [ [line_number_to_change1, line_number_to_change2, ... line_number_to_changen], 
-[ 2 ], [ 0, -1.5 ], [  ], "linear" ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type:"linear"_or_"rotation2d" ]; 
+[ 2 ], [ 0, -1.5 ], [  ], "linear", ","  ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type:"linear"_or_"rotation2d" ]; 
 ]
 ]
 ]
@@ -291,7 +286,7 @@ $vals{1}{5}{genchange} =  #THIS MEANS: CHANGE OF "generic" TYPE, WHICH ARE TRASF
 [ # BKACKET DELIMITING THIS GROUP OF ACTIONS. THERE IS ONLY ONE GROUP OF ACTIONS IN THIS GROUP OF OPERATIONS.
 "/ep/newbox21.idf", # FILE TO BE MODIFIED.
 [ [ 109, 112, 124, 127, 139, 142, 154, 157, 169, 170, 171, 172 ], # FIRST CHANGE TO BE MADE. THIS MEANS: [ [line_number_to_change1, line_number_to_change2, ... line_number_to_changen], 
-[ 3 ], [ 0, 4 ], [  ], "linear" ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type:"linear"_or_"rotation2d" ]; 
+[ 3 ], [ 0, 4 ], [  ], "linear", ","  ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type:"linear"_or_"rotation2d" ]; 
 ]
 ]
 ]
@@ -315,7 +310,7 @@ $vals{1}{6}{genchange} =  #THIS MEANS: CHANGE OF "generic" TYPE, WHICH ARE TRASF
 289, 290, 291, 292, 304, 305, 306, 307, 319, 320, 321, 322, 334, 335, 336, 337, 349, 350, 351, 352, 364, 365, 366, 367,
 379, 380, 381, 382, 394, 395, 396, 397, 409, 410, 411, 412, 424, 425, 426, 427, 439, 440, 441, 442, 454, 455, 456, 457,
 490, 491, 492, 493, 506, 507, 508, 509, 522, 523, 524, 525, 538, 539, 540, 541, 554, 555, 556, 557, 570, 571, 572, 573 ], # FIRST CHANGE TO BE MADE. THIS MEANS: [ [line_number_to_change1, line_number_to_change2, ... line_number_to_changen], 
-[ 1, 2 ], [ -135, 180 ], [  ], "rotation2d" ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type:"linear"_or_"rotation2d" ]; 
+[ 1, 2 ], [ -135, 180 ], [  ], "rotation2d", ",", [ 0, 0 ] ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type:"linear"_or_"rotation2d", [ centre_x, centrey] , "," ];  NOTE THAT "," is the separator of items. it can be " " as an alternative for example. 
 ]
 ]
 ]
@@ -333,7 +328,7 @@ $vals{1}{7}{genchange} =  #THIS MEANS: CHANGE OF "generic" TYPE, WHICH ARE TRASF
 [ # BKACKET DELIMITING THIS GROUP OF ACTIONS. THERE IS ONLY ONE GROUP OF ACTIONS IN THIS GROUP OF OPERATIONS.
 "/ep/newbox21.idf", # FILE TO BE MODIFIED.
 [ [ 936 ], # FIRST CHANGE TO BE MADE. THIS MEANS: [ [line_number_to_change1, line_number_to_change2, ... line_number_to_changen], 
-[ 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13 ], [ 0, 0.6 ], [  ], "linear" ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type:"linear"_or_"rotation2d" ]; 
+[ 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13 ], [ 0, 0.6 ], [  ], "linear", "," ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type:"linear"_or_"rotation2d" ]; 
 ]
 ]
 ]
